# RuleQueryParameters

Each instance maps a particular query parameter to a set of constraints.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the query parameter. | 
**exact_match** | **str** | The given query parameter must exist and equal this. Can be templatized with jinja2 using the definitions collection.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


